/*
  Rhino test framework

   Copyright (C) 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.RhinoTests.Reporter;

import java.util.Locale;



/**
 * Some useful static methods for string handling.
 * 
 * @author Pavel Tisnovsky
 */
public class StringUtils {

	/**
     * Get substring from given string in case that both delimiters are strings
     * too.
     * 
     * @param string
     *            given input string
     * @param startDelimiter
     *            first delimiter
     * @param stopDelimiter
     *            second delimiter
     * @return substring a new string which is a substring of given input string
     */
    public static String getSubstring(String string, String startDelimiter, String stopDelimiter) {
        // avoid NPE
        if (string == null) {
            return null;
        }
        int startDelimiterIndex = startDelimiter == null ? 0 : string.indexOf(startDelimiter);
        int stopDelimiterIndex = stopDelimiter == null ? string.length() : string.indexOf(stopDelimiter);
        int startDelimiterLength = startDelimiter == null ? 0 : startDelimiter.length();
        // when delimiters are not found, return null string
        if (startDelimiterIndex == -1) {
            return null;
        }
        if (stopDelimiterIndex == -1) {
            return null;
        }
        String s = string.substring(startDelimiterIndex + startDelimiterLength, stopDelimiterIndex);
        // trim unnecessary leading and trailing whitespace characters
        return s.trim();
    }

	/**
	 * Convert UPPER_CASE_STYLE name into a CamelCase
	 * 
	 * @param string
	 *            input string which could contains names divided by underscore
	 *            character
	 * @return camel case variant of the input string
	 */
    public static String toCamelCase(String string) {
    	// all underscores (+character after it) should be replaced by the
    	// uppercased variant of this character
		String[] parts = string.split("_");
		StringBuffer camelCaseString = new StringBuffer();
		// properly convert all words (which were separated by underscore)
		for (String part : parts) {
			camelCaseString.append(convertToProperCase(part));
		}
		return camelCaseString.toString();
	}

	/**
	 * Convert a string to a new form where the first letter is upper case and
	 * other letters are lower case
	 * 
	 * @param string
	 *            input string
	 * @return input string with capitalized first letter
	 */
	public static String convertToProperCase(String string) {
		return string.substring(0, 1).toUpperCase(Locale.ENGLISH) + string.substring(1).toLowerCase(Locale.ENGLISH);
	}

	/**
	 * Convert "PLACEHOLDER_NAME" into the name of the getter:
	 * "getPlaceholderName"
	 * 
	 * @param placeholderName
	 * @return
	 */
	public static String getPlaceholderMethodName(String placeholderName) {
		String temporaryName = placeholderName.substring(1);
		temporaryName = temporaryName.substring(1, temporaryName.length() - 1);
		temporaryName = "get" + StringUtils.toCamelCase(temporaryName.toLowerCase(Locale.ENGLISH));
		return temporaryName;
	}

}
